@@ -7,7 +7,7 @@ Attean::API::Binding - Name to term bindings
 
 =head1 VERSION
 
-This document describes Attean::API::Binding version 0.002
+This document describes Attean::API::Binding version 0.003
 
 =head1 DESCRIPTION
 
@@ -106,6 +106,11 @@ package Attean::API::Binding 0.001 {
 		my @blanks	= grep { $_->does('Attean::API::Blank') } $self->values;
 		return scalar(@blanks);
 	}
+	
+	sub tree_attributes {
+		my $self	= shift;
+		return $self->variables;
+	};
 }
 
 package Attean::API::TripleOrQuadPattern 0.001 {
