@@ -7,7 +7,7 @@ Attean::API::Store - Triple/quad store role
 
 =head1 VERSION
 
-This document describes Attean::Store version 0.001
+This document describes Attean::Store version 0.003
 
 =head1 DESCRIPTION
 
@@ -19,13 +19,17 @@ The Attean::Store role is an empty role that more specialized roles conform to:
 
 =item * L<Attean::API::MutableTripleStore>
 
-=item * L<Attean::API::CacheableTripleStore>
+=item * L<Attean::API::ETagCacheableTripleStore>
+
+=item * L<Attean::API::TimeCacheableTripleStore>
 
 =item * L<Attean::API::QuadStore>
 
 =item * L<Attean::API::MutableQuadStore>
 
-=item * L<Attean::API::CacheableQuadStore>
+=item * L<Attean::API::ETagCacheableQuadStore>
+
+=item * L<Attean::API::TimeCacheableQuadStore>
 
 =back
 
@@ -51,6 +55,11 @@ package Attean::API::TripleStore 0.001 {
 		return $count;
 	}
 	
+	sub count_triples_estimate {
+		my $self	= shift;
+		return $self->count_triples(@_);
+	}
+	
 	sub size {
 		my $self	= shift;
 		return $self->count_triples();
@@ -65,13 +74,20 @@ package Attean::API::MutableTripleStore 0.001 {
 	requires 'remove_triple';
 }
 
-package Attean::API::CacheableTripleStore 0.001 {
+package Attean::API::ETagCacheableTripleStore 0.001 {
 	use Moo::Role;
 	with 'Attean::API::TripleStore';
 	
 	requires 'etag_value_for_triples';
 }
 
+package Attean::API::TimeCacheableTripleStore 0.001 {
+	use Moo::Role;
+	with 'Attean::API::TripleStore';
+	
+	requires 'mtime_for_triples';
+}
+
 package Attean::API::QuadStore 0.001 {
 	use Moo::Role;
 	with 'Attean::API::Store';
@@ -88,6 +104,11 @@ package Attean::API::QuadStore 0.001 {
 		return $count;
 	}
 	
+	sub count_quads_estimate {
+		my $self	= shift;
+		return $self->count_quads(@_);
+	}
+	
 	sub get_graphs {
 		my $self	= shift;
 		my $iter	= $self->get_quads(@_);
@@ -127,13 +148,20 @@ package Attean::API::MutableQuadStore 0.001 {
 	}
 }
 
-package Attean::API::CacheableQuadStore 0.001 {
+package Attean::API::ETagCacheableQuadStore 0.001 {
 	use Moo::Role;
 	with 'Attean::API::QuadStore';
 	
 	requires 'etag_value_for_quads';
 }
 
+package Attean::API::TimeCacheableQuadStore 0.001 {
+	use Moo::Role;
+	with 'Attean::API::QuadStore';
+	
+	requires 'mtime_for_quads';
+}
+
 1;
 
 __END__
