@@ -4,7 +4,7 @@ AtteanX::Serializer::NQuads - N-Triples Serializer
 
 =head1 VERSION
 
-This document describes AtteanX::Serializer::NQuads version 0.001
+This document describes AtteanX::Serializer::NQuads version 0.003
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,17 @@ package AtteanX::Serializer::NQuads 0.001 {
 
 	extends 'AtteanX::Serializer::NTuples';
 	has 'canonical_media_type' => (is => 'ro', isa => Str, init_arg => undef, default => 'application/n-quads');
-	has 'media_types' => (is => 'ro', isa => ArrayRef[Str], init_arg => undef, default => sub { ['application/n-quads'] });
+
+=item C<< media_types >>
+
+Returns a list of media types that identify the format produced by this serializer.
+
+=cut
+
+	sub media_types {
+		return [qw(application/n-quads)];
+	}
+
 	with 'Attean::API::MixedStatementSerializer';
 	with 'Attean::API::AppendableSerializer';
 }
